Installation — Projy 0.1 documentation

### Navigation

- index
- next |
- previous |
- Projy 0.1 documentation »

# Installation

If you are familiar with Python, it is strongly suggested that you install Projy in virtualenv.

## Pip and Distribute

To install Projy, just type:

    $ sudo pip install projy

If no pip available, try `easy_install`:

    $ sudo easy_install projy

## Install with git

If you prefer git, that is ok too. You can get the very latest code at GitHub:

    $ git clone http://github.com/stephanepechard/projy

### Navigation

- index
- next |
- previous |
- Projy 0.1 documentation »